netapp_ontap.models.security_proxy API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.security_proxy`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class SecurityProxySchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the SecurityProxy object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `host: str POST`

    Proxy host.

    Example: proxy.eng.com

  `password: str POST`

    Proxy password. Password is not audited.

    Example: proxypassword

  `port: Size POST`

    Proxy port.

    Example: 1234

  `type: str POST`

    Proxy type.

    Valid choices:

    - http
    - https
  `username: str POST`

    Proxy username.

    Example: proxyuser